# Python control for WiLight devices

A simple Python API for controlling devices from WiLight, developed for integration with Home Assistant. At present, the following devices are currently supported:

- I-100
- I-102
- C-103
- V-104
- R-105
- I-107
